@@ -1,4 +1,4 @@
-from .init import Module
+from setux.core.module import Module
 
 
 class Distro(Module):
@@ -20,7 +20,7 @@ class Distro(Module):
         full = f'{path}/{name}'
 
         ok = target.Dir(
-            path, mode='700', user=usr, group=user.group
+            path, mode='700', user=usr, group=user.group.name
         ).deploy()
 
         if not ok:
@@ -29,7 +29,7 @@ class Distro(Module):
         target.send(pub, full)
 
         ok = target.File(
-            full, mod='600', usr=usr, grp=user.group
+            full, mod='600', usr=usr, grp=user.group.name
         ).deploy()
 
         return ok
