@@ -1,6 +1,6 @@
 from setux.core import __version__
-
-from .init import Module, info
+from setux.logger import info
+from setux.core.module import Module
 
 
 class Distro(Module):
